@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Carp 'croak';
 use Module::Load 'load';
-use Evo::Util;
+use Evo::Lib::Bare;
 use feature 'say';
 
 
@@ -15,9 +15,9 @@ sub _parse {
   $val =~ tr/\n/ /;
   $val =~ s/^\s+|\s+$//g;
 
-  $val =~ /^ ((\-|\:\:|\:)? $Evo::Util::RX_PKG_NOT_FIRST*) (.*)$/x;
+  $val =~ /^ ((\-|\:\:|\:)? $Evo::Lib::Bare::RX_PKG_NOT_FIRST*) (.*)$/x;
   croak qq#Can't parse string "$orig"# unless $1;
-  my ($class, $args) = (Evo::Util::resolve_package($caller, $1), $3);
+  my ($class, $args) = (Evo::Lib::Bare::resolve_package($caller, $1), $3);
 
   $args =~ s/^$ARGS_RX$/$1/;
   return ($class) unless $args;
@@ -38,8 +38,12 @@ sub import {
     my ($class, @args) = _parse($target, $key);
     load($class);
     if (my $import = $class->can('import')) {
-      Evo::Util::inject(package => $target, line => $line, filename => $filename, code => $import)
-        ->($class, @args);
+      Evo::Lib::Bare::inject(
+        package  => $target,
+        line     => $line,
+        filename => $filename,
+        code     => $import
+      )->($class, @args);
     }
     elsif (@args) {
       croak qq#Got import arguments but $class hasn't "import" method#;
@@ -50,7 +54,7 @@ sub import {
 
 1;
 
-our $VERSION = '0.0200';    # VERSION
+our $VERSION = '0.0201';    # VERSION
 
 # ABSTRACT: Evo - the next generation component-oriented development framework
 
@@ -66,7 +70,7 @@ Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 DESCRIPTION
 
@@ -103,6 +107,10 @@ L<Evo::Ee> - a component role that gives your component "EventEmitter" abilities
   # enables strict, warnings, utf8, :5.22, signatures, postderef
   use Evo;
 
+=head1 STATE
+
+This module is under active development. It changes often and a lot! Don't use in production. Get involved L<https://github.com/alexbyk/perl-evo>
+
 =head1 VIM
 
 =for HTML <p><img src="https://raw.github.com/alexbyk/perl-evo/master/demo.gif" alt="Perl Evo gif" /></p>
@@ -165,7 +173,7 @@ I have decided that using 5.22 and some of the experimental features it brings h
 =head2 -Loaded
 
 This marks inline or generated classes as loaded, so can be used with
-C<require> or C<use>. So this code won't die
+C<require> or C<use>. So this code won't die. Used for test and examples in the documentation
 
   require My::Inline;
 
