@@ -1,8 +1,6 @@
 package Evo::Comp::Out;
 use Evo '-Export *';
-use Evo::Lib 'monkey_patch';
-use Evo '::Gen::HUF GEN; -Role ROLE_EXPORTER';
-use Evo '::Meta';
+use Evo '::Gen::HUF GEN; -Role ROLE_EXPORTER; ::Meta';
 
 my $META = Evo::Comp::Meta::new(gen => GEN, rex => ROLE_EXPORTER);
 
@@ -25,8 +23,8 @@ export_anon MODIFY_CODE_ATTRIBUTES => sub($class, $code, @attrs) {
   my @bad = grep { $_ ne 'Override' } @attrs;
   return @bad if @bad;
 
-  Evo::Util::find_subnames($class, $code);
-  $META->mark_overriden($class, Evo::Util::find_subnames($class, $code));
+  Evo::Lib::Bare::find_subnames($class, $code);
+  $META->mark_overriden($class, Evo::Lib::Bare::find_subnames($class, $code));
   return;
 };
 
@@ -45,7 +43,7 @@ Evo::Comp::Out
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 DESCRIPTION
 
