@@ -1,5 +1,5 @@
 package Evo::Loop;
-use Evo '-Realm *; -Export *';
+use Evo '-Export *';
 use Evo ':Comp';
 
 use constant DEFAULT => Evo::Loop::Comp::new();
@@ -16,6 +16,7 @@ sub loop_io_error : Export      { DEFAULT->realm_lord->io_error(@_) }
 sub loop_io_remove_in : Export  { DEFAULT->realm_lord->io_remove_in(@_); }
 sub loop_io_remove_out : Export { DEFAULT->realm_lord->io_remove_out(@_); }
 sub loop_io_remove_all : Export { DEFAULT->realm_lord->io_remove_all(@_); }
+sub loop_io_remove_fd : Export  { DEFAULT->realm_lord->io_remove_fd(@_); }
 
 sub loop_zone : Export                    { DEFAULT->realm_lord->zone(@_) }
 sub loop_postpone : prototype(&) : Export { DEFAULT->realm_lord->postpone(@_) }
@@ -34,7 +35,7 @@ Evo::Loop
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 AUTHOR
 
