@@ -1,5 +1,5 @@
 package Evo::Loop::Comp;
-use Evo '-Comp *', '-Lib steady_time', '-Realm *';
+use Evo '-Comp *', '-Lib::Internal steady_time', '-Realm *';
 use List::Util 'first';
 use Time::HiRes 'usleep';
 
@@ -63,7 +63,7 @@ Evo::Loop::Comp
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 AUTHOR
 
