@@ -1,6 +1,5 @@
 package Evo::Loop::Role::Zone;
-use Evo '-Role *';
-use Evo::Lib '*';
+use Evo '-Role *; -Lib::Internal *';
 use Carp 'croak';
 
 has zone_data => sub { {} };
@@ -43,7 +42,7 @@ Evo::Loop::Role::Zone
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 AUTHOR
 
