@@ -1,6 +1,6 @@
 package Evo::Realm;
-use Evo '-Export *', '-Lib *';
-use Evo::Util;
+use Evo '-Export *';
+use Evo::Lib::Bare;
 use Carp 'croak';
 use Scalar::Util qw(refaddr blessed);
 
@@ -37,7 +37,7 @@ Evo::Realm
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSYS
 
